// -----------------------------------------------------------------------------
// Copyright 2009 Patrick Näf (herzbube@herzbube.ch)
//
// This file is part of the dgsmonX project.
//
// dgsmonX is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// dgsmonX is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with dgsmonX. If not, see <http://www.gnu.org/licenses/>.
// -----------------------------------------------------------------------------


// Forward declarations
@class DGSMonXServer;


// -----------------------------------------------------------------------------
/// @class DGSMonXServerMenuItem
///
/// @brief The DGSMonXServerMenuItem class is used to represent a DGSMonXServer
/// in the application's status menu.
///
/// DGSMonXServerMenuItem is responsible for setting up the menu item's visual
/// representation in the style governed by the current user defaults (e.g.
/// single menu item or sub-menu), using the server's current attribute values
/// (e.g. name, most recent game state check results).
///
/// DGSMonXServerMenuItem updates its visual representation when it receives
/// the update() message. The message must be sent after DGSMonXServerMenuItem
/// has been constructed, otherwise DGSMonXServerMenuItem will display an empty
/// menu item.
///
/// DGSMonXServerMenuItem is @b not responsible for placing itself into a
/// parent NSMenu, nor for selecting a position within its parent NSMenu, nor
/// for removing itself from the parent NSMenu.
// -----------------------------------------------------------------------------
@interface DGSMonXServerMenuItem : NSMenuItem
{
@private
  /// @brief The server that this menu item represents.
  DGSMonXServer* m_server;
}

/// @name Initializers
//@{
- (id) initWithServer:(DGSMonXServer*)server;
//@}

/// @name Server accessor
//@{
- (DGSMonXServer*) server;
//@}

/// @name Update visual representation
//@{
- (void) update;
//@}

@end
